﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win.UltraWinSchedule;

namespace WinScheduleDataBinding
{
    public partial class Form1 : Form
    {
        DataSet ds;
        bool newData = true;

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            // Get the Sample Data required for Appointments and Owners data binding
            ds = this.GetSampleData();
            
            BidnCalendarInfo(ref ultraCalendarInfo1);
            ultraTimelineView1.VisibleDateTimeRangeChanged +=new VisibleDateTimeRangeChangedHandler(ultraTimelineView1_VisibleDateTimeRangeChanged);

        }

        

        private void BidnCalendarInfo(ref UltraCalendarInfo info )
        {
            // Hide the Unassigned Owner
            info.Owners.UnassignedOwner.Visible = false;

            // Bind ultraCalendarInfo to Appointments Data Table
            info.DataBindingsForAppointments.DataSource = ds.Tables["Appointments"];

            ds.Tables["Appointments"].RowChanged += new DataRowChangeEventHandler(Form1_RowChanged);
            ds.Tables["Appointments"].TableNewRow += new DataTableNewRowEventHandler(Form1_TableNewRow);
            ds.Tables["Appointments"].RowDeleting += new DataRowChangeEventHandler(Form1_RowDeleting);
            // Bind ultraCalendarInfo to Owners Data Table
            info.DataBindingsForOwners.DataSource = ds.Tables["Owners"];

            // Set Appointments data binding properties to UltraCalendarInfo
            info.DataBindingsForAppointments.StartDateTimeMember = "StartTime";

            info.DataBindingsForAppointments.EndDateTimeMember = "EndTime";

            info.DataBindingsForAppointments.SubjectMember = "Subject";
            info.DataBindingsForAppointments.RecurrenceMember = "RecurrenceMember";
            info.DataBindingsForAppointments.OwnerKeyMember = "OwnerKey";
            info.DataBindingsForAppointments.AllPropertiesMember = "AllPropertiesMember";

            // Set Owners data binding properties to UltraCalendarInfo
            info.DataBindingsForOwners.KeyMember = "OwnerKey";
            info.DataBindingsForOwners.NameMember = "Name";

            if (info.Equals(ultraCalendarInfo1) && newData)
            {
                DateTime date = DateTime.Now.AddDays(-3);
                date = new DateTime(date.Year, date.Month, date.Day, 11, 00, 00);

                Appointment app = new Appointment(date, date.AddHours(2));
                app.Subject = "Delete ME!";
                //app.Description = 
                app.Recurrence = new AppointmentRecurrence();
                app.Recurrence.PatternFrequency = RecurrencePatternFrequency.Daily;

                app.Owner = ultraCalendarInfo1.Owners[1];
                ultraCalendarInfo1.Appointments.Add(app);
            }

            // Assign CalendarInfo component to TimelineView control
            //this.ultraTimelineView1.CalendarInfo = this.ultraCalendarInfo1;

            // Set UltraCalendarLook ViewStyle
            //this.ultraTimelineView1.ViewStyle = Infragistics.Win.UltraWinSchedule.ViewStyle.Office2007;

            // Assign CalendarLook component to TimeLineView control
            //this.ultraTimeLineView1.CalendarLook = this.ultraCalendarLook1;
        }

        void Form1_RowDeleting(object sender, DataRowChangeEventArgs e)
        {
            string format = "";
            for (int i = 0; i < e.Row.ItemArray.Count(); i++)
            {
                format += string.Format(" {0}{1}{2} ","{", i,"}");
            }
            MessageBox.Show(string.Format(format, e.Row.ItemArray),"Add method whic will REMOVE the following row from your dtabase");
          
        }

       

        void Form1_TableNewRow(object sender, DataTableNewRowEventArgs e)
        {
            string format = "";
            for (int i = 0; i < e.Row.ItemArray.Count(); i++)
            {
                format += string.Format(" {0}{1}{2} ", "{", i, "}");
            }
            MessageBox.Show(string.Format(format, e.Row.ItemArray), "Add method whic will ADD the following row from your dtabase");
        }

        void Form1_RowChanged(object sender, DataRowChangeEventArgs e)
        {
            string format = "";
            for (int i = 0; i < e.Row.ItemArray.Count(); i++)
            {
                format += string.Format(" {0}{1}{2} ", "{", i, "}");
            }
            MessageBox.Show(string.Format(format, e.Row.ItemArray), "Add method whic will UPDATE the following row from your dtabase");
        }

        private DataSet GetSampleData()
        {
            DataSet theDataSet = new DataSet();

            try
            {
                theDataSet.ReadXmlSchema("TestS.XML");
                theDataSet.ReadXml("Test.XML");
                newData = false;
            }
            catch
            {
                // Create Appointments DataTable
                DataTable theAppointments = theDataSet.Tables.Add("Appointments");
                theAppointments.Columns.Add("AppointmentID", typeof(int));
                theAppointments.Columns.Add("StartTime", typeof(DateTime));
                theAppointments.Columns.Add("EndTime", typeof(DateTime));
                theAppointments.Columns.Add("Subject", typeof(string));
                theAppointments.Columns.Add("OwnerKey", typeof(string));
                theAppointments.Columns.Add("RecurrenceMember", typeof(object));
                theAppointments.Columns.Add("AllPropertiesMember", typeof(object));

                // Add Appointments Sample Data
                theAppointments.Rows.Add(new object[] { "1", string.Format("{0}/{1}/2012 9:00:00 AM",DateTime.Now.Month , DateTime.Now.Day), string.Format("{0}/{1}/2012 10:00:00 AM",DateTime.Now.Month , DateTime.Now.Day), "Sprint Review", "Charlie" });
                theAppointments.Rows.Add(new object[] { "1", string.Format("{0}/{1}/2012 8:00:00 AM",DateTime.Now.Month , DateTime.Now.Day), string.Format("{0}/{1}/2012 8:30:00 AM",DateTime.Now.Month , DateTime.Now.Day), "Scrum Meet", "Jamie" });
                theAppointments.Rows.Add(new object[] { "1", string.Format("{0}/{1}/2012 9:00:00 AM",DateTime.Now.Month , DateTime.Now.Day), string.Format("{0}/{1}/2012 9:30:00 AM",DateTime.Now.Month , DateTime.Now.Day), "Status Meeting", "Lukas" });
                theAppointments.Rows.Add(new object[] { "1", string.Format("{0}/{1}/2012 8:45:00 AM", DateTime.Now.Month, DateTime.Now.Day), string.Format("{0}/{1}/2012 9:00:00 AM", DateTime.Now.Month, DateTime.Now.Day), "Feature Review", "Lopez" });

                // Create Owners DataTable
                DataTable theOwners = theDataSet.Tables.Add("Owners");
                theOwners.Columns.Add("OwnerID", typeof(int));
                theOwners.Columns.Add("Name", typeof(string));
                theOwners.Columns.Add("OwnerKey", typeof(string));

                // Add Owners Sample Data
                theOwners.Rows.Add(new object[] { "1", "Maria Charlie", "Charlie" });
                theOwners.Rows.Add(new object[] { "2", "John Jamie", "Jamie" });
                theOwners.Rows.Add(new object[] { "3", "Matthew Lukas", "Lukas" });
                theOwners.Rows.Add(new object[] { "4", "Leah Lopez", "Lopez" });
            }
            return theDataSet;
        }

        private void ultraGrid1_DoubleClickCell(object sender, Infragistics.Win.UltraWinGrid.DoubleClickCellEventArgs e)
        {

        }

        private void ultraButton1_Click(object sender, EventArgs e)
        {
            ds.WriteXml("Test.XML");
            ds.WriteXmlSchema("TestS.XML");

        }

        private void ultraTimelineView1_VisibleDateTimeRangeChanged(object sender, VisibleDateTimeRangeChangedEventArgs e)
        {
           
        }

        
      
    }
}
